@@ -91,7 +91,6 @@ ARGUMENT_RENAMES = {
     'license-manager.get-grant.version': 'grant-version',
     'license-manager.delete-grant.version': 'grant-version',
     'license-manager.get-license.version': 'license-version',
-    'mobile.create-project.region': 'project-region',
     'rekognition.create-stream-processor.output': 'stream-processor-output',
     'eks.create-cluster.version': 'kubernetes-version',
     'eks.update-cluster-version.version': 'kubernetes-version',
@@ -106,6 +105,11 @@ ARGUMENT_RENAMES = {
     'codepipeline.get-action-type.version': 'action-version',
     'ecs.*.no-enable-execute-command': 'disable-execute-command',
     'ecs.execute-command.no-interactive': 'non-interactive',
+    'controltower.create-landing-zone.version': 'landing-zone-version',
+    'controltower.update-landing-zone.version': 'landing-zone-version',
+    'glue.get-unfiltered-partition-metadata.region': 'resource-region',
+    'glue.get-unfiltered-partitions-metadata.region': 'resource-region',
+    'glue.get-unfiltered-table-metadata.region': 'resource-region',
 }
 
 # Same format as ARGUMENT_RENAMES, but instead of renaming the arguments,
